==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/options/BuildStringDialog.cpp <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#include <QtGui>


#include "../main/includes/httraqt.h"
#include "includes/BuildStringDialog.h"


BuildStringDialog::BuildStringDialog(QWidget *parent)
    : QDialog(parent)
{
    setupUi(this);

    this->parent = (HTTraQt*)parent;

    initTextPoints();

    setWindowTitle(translateString(_USERDEFSTRUCT));
    connect(okButton, SIGNAL(clicked()), this, SLOT(onOk()));
    connect(pushButton, SIGNAL(clicked()), this, SLOT(reject()));
}


void BuildStringDialog::onOk()
{
    QString st;
    st = lineEdit->text();
    parent->SetProfile("BuildString", st);

    accept();
}


void BuildStringDialog::initTextPoints()
{
    QString st;
    label->setText(translateString(_Q2));
    label_2->setText(translateString(_Q3));

    parent->GetProfile("BuildString", st);
    lineEdit->setText(st);
}

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/options/BuildStringDialog.cpp <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#include <QtGui>


#include "../main/includes/httraqt.h"
#include "includes/BuildStringDialog.h"


BuildStringDialog::BuildStringDialog(QWidget *parent)
    : QDialog(parent)
{
    setupUi(this);

    this->parent = static_cast<HTTraQt*>(parent);

    initTextPoints();

    setWindowTitle(translate(_USERDEFSTRUCT));
    connect(okButton, SIGNAL(clicked()), this, SLOT(onOk()));
    connect(pushButton, SIGNAL(clicked()), this, SLOT(reject()));
}


void BuildStringDialog::onOk()
{
    QString st;
    st = lineEdit->text();
    parent->SetProfile("BuildString", st);

    accept();
}


void BuildStringDialog::initTextPoints()
{
    QString st;
    label->setText(translate(_Q2));
    label_2->setText(translate(_Q3));

    parent->GetProfile("BuildString", st);
    lineEdit->setText(st);
}
